package com.zehong.system.service.impl;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TWorkOrderMapper;
import com.zehong.system.domain.TWorkOrder;
import com.zehong.system.service.ITWorkOrderService;

/**
 * 燃气任务Service业务层处理
 * 
 * @author zehong
 * @date 2022-02-10
 */
@Service
public class TWorkOrderServiceImpl implements ITWorkOrderService 
{
    @Autowired
    private TWorkOrderMapper tWorkOrderMapper;

    /**
     * 查询燃气任务
     * 
     * @param workId 燃气任务ID
     * @return 燃气任务
     */
    @Override
    public TWorkOrder selectTWorkOrderById(Long workId)
    {
        return tWorkOrderMapper.selectTWorkOrderById(workId);
    }

    /**
     * 查询燃气任务列表
     * 
     * @param tWorkOrder 燃气任务
     * @return 燃气任务
     */
    @Override
    public List<TWorkOrder> selectTWorkOrderList(TWorkOrder tWorkOrder)
    {
        return tWorkOrderMapper.selectTWorkOrderList(tWorkOrder);
    }

    /**
     * 新增燃气任务
     * 
     * @param tWorkOrder 燃气任务
     * @return 结果
     */
    @Override
    public int insertTWorkOrder(TWorkOrder tWorkOrder)
    {
        tWorkOrder.setCreateTime(DateUtils.getNowDate());
        return tWorkOrderMapper.insertTWorkOrder(tWorkOrder);
    }

    /**
     * 修改燃气任务
     * 
     * @param tWorkOrder 燃气任务
     * @return 结果
     */
    @Override
    public int updateTWorkOrder(TWorkOrder tWorkOrder)
    {
        tWorkOrder.setUpdateTime(DateUtils.getNowDate());
        return tWorkOrderMapper.updateTWorkOrder(tWorkOrder);
    }

    /**
     * 批量删除燃气任务
     * 
     * @param workIds 需要删除的燃气任务ID
     * @return 结果
     */
    @Override
    public int deleteTWorkOrderByIds(Long[] workIds)
    {
        return tWorkOrderMapper.deleteTWorkOrderByIds(workIds);
    }

    /**
     * 删除燃气任务信息
     * 
     * @param workId 燃气任务ID
     * @return 结果
     */
    @Override
    public int deleteTWorkOrderById(Long workId)
    {
        return tWorkOrderMapper.deleteTWorkOrderById(workId);
    }
}
